@@ -19,13 +19,12 @@ import { Signal } from '@lumino/signaling';
 import { User } from "./models/User";
 import { OptumiMetadataTracker } from "./models/OptumiMetadataTracker";
 import { Snackbar } from "./models/Snackbar";
-import ExpScaleUtils from "./utils/ExpScaleUtils";
-import { DataConnectorMetadata } from "./components/deploy/dataConnectorBrowser/DataConnectorBrowser";
 import { Machine, NoMachine } from "./models/machine/Machine";
 
 import { SnackbarKey } from "notistack";
 import { Accordion, AccordionDetails, AccordionSummary, alpha, Button, Dialog, MenuItem, Select } from '@mui/material';
 import { withStyles } from '@mui/styles';
+import { IntegrationMetadata } from './components/deploy/IntegrationBrowser/IntegrationBrowser';
 
 /**
  * The method to change the extension to be a certain view
@@ -43,13 +42,14 @@ type Target = {
 
 export class Global {
 
-    // The members in Target can be for dependency (we must switch to the deploy tab before switching to export mode) or they
+    // The members in Target can be for dependency (we must switch to the deploy tab before switching to expert mode) or they
     // can be for organization (the settings popup doesn't do anything to prep its children, but it makes it easier to read)
     public static readonly Target = {
         SettingsPopup: {
             PreferencesTab: {},
             LimitsTab: {},
             ConnectorsTab: {},
+            IntegrationsTab: {},
             StorageTab: {},
             BillingTab: {},
         },
@@ -127,11 +127,6 @@ export class Global {
     public static bounceAnimation = 'all 333ms cubic-bezier(0.33, 1.33, 0.66, 1) 0s'
     public static easeAnimation = 'all 150ms ease 0s'
 
-    public static capitalizeFirstLetter(value: string) {
-        if (value === null || value.length == 0) return value
-        return value.charAt(0).toUpperCase() + value.slice(1);
-    }
-
     public static MAX_UPLOAD_SIZE = 5 * 1024 * 1024 * 1024
 
     // Which public stripe key we are using
@@ -278,10 +273,8 @@ export class Global {
             Global.consecutive401s = 0;
             // Reset cached info
             Global.lastMachineRate = 0;
-            Global.lastCreditsCost = 0;
             Global.lastCreditsBalance = 0;
-            Global.lastBudgetCost = 0;
-            Global.lastDataConnectors = [];
+            Global.lastIntegrations = [];
             Global.lastMachine = new NoMachine();
 
             if (user != null && !user.unsignedAgreement) {
@@ -307,36 +300,24 @@ export class Global {
     public static snackbarEnqueue: Signal<Global, Snackbar> = new Signal<Global, Snackbar>(Global.emitter);
     public static snackbarClose: Signal<Global, SnackbarKey> = new Signal<Global, SnackbarKey>(Global.emitter);
     public static dataConnectorChange: Signal<Global, void> = new Signal<Global, void>(Global.emitter);
+    public static environmentVariableChange: Signal<Global, void> = new Signal<Global, void>(Global.emitter);
     public static forcePackageIntoView: Signal<Global, void> = new Signal<Global, void>(Global.emitter);
     public static lastForceCompleted: boolean = true;
 
     // We will keep some state here to avoid having no information to show before a request returns
     public static lastMachineRate: number = 0;
-    public static lastCreditsCost: number = 0;
     public static lastCreditsBalance: number = 0;
-    public static lastBudgetCost: number = 0;
-    public static lastDataConnectors: DataConnectorMetadata[] = [];
+    public static lastIntegrations: IntegrationMetadata[] = [];
     public static lastMachine: Machine = new NoMachine();
 
     public static packagesAccordionExpanded: boolean = false
+    public static environmentVariablesAccordionExpanded: boolean = false
     public static filesAccordionExpanded: boolean = false
     public static launchModeAccordionExpanded: boolean = false
     public static expertModeSelected: boolean = false
 
     public static dismissalTimeout: number = 1.44e+7
 
-    // We will use these for the steps for fractions
-    private static generateFractionSteps = () => {
-        const steps = new ExpScaleUtils(0, 1, 0.01, 1, true).getMarks();
-        steps.unshift(
-            {
-                value: -1,
-            }
-        );
-        return steps;
-    }
-    public static fractionMarks: any[] = Global.generateFractionSteps();
-
     private static consecutive401s = 0;
 
     // This function will update the consecutive 401s properly and throw exceptions if the request failed
@@ -425,7 +406,7 @@ export const WhiteTextButton = withStyles({
 export const SkinnyButton = withStyles({
     root: {
         height: '20px',
-        padding: '0px',
+        padding: '0px 6px',
         fontSize: '12px',
         lineHeight: '12px',
         minWidth: '0px',
