@@ -6,14 +6,14 @@
 **/
 
 import * as React from 'react'
-import { Global } from '../Global';
+import { DIV, Global } from '../Global';
 
-import { Slider, Theme, withStyles, withTheme } from '@material-ui/core';
-import { CSSProperties } from '@material-ui/styles';
+import { SxProps, Theme } from '@mui/system';
+import { Slider } from '@mui/material';
+import { withStyles } from '@mui/styles';
 
 interface IProps {
-    style?: CSSProperties
-    theme: Theme
+    sx?: SxProps<Theme>
     label: string
     min?: number
     step?: number
@@ -35,7 +35,7 @@ var retrievingPreview: boolean = false;
 var updatePreviewAgain: boolean = false;
 var latestValue: number[];
 
-class ChipSlider extends React.Component<IProps, IState> {
+export class ChipSlider extends React.Component<IProps, IState> {
     _isMounted = false;
     close: () => void = () => {}
     stopPropagation: () => void = () => {}
@@ -67,16 +67,14 @@ class ChipSlider extends React.Component<IProps, IState> {
             thumb: {
                 height: '18px',
                 width: '18px',
-                marginTop: '-6px',
-                marginLeft: '-9px',
                 '&:focus, &:hover, &$active': {
                     boxShadow: '0px 0px 0px 7px ' + props.color + '29',
                 },
                 '&.Mui-disabled': {
                     width: '12px',
                     height: '12px',
-                    marginTop: '-3px',
-                    marginLeft: '-6px',
+                    // marginTop: '-3px',
+                    // marginLeft: '-6px',
                 }
             },
             mark: {
@@ -84,6 +82,7 @@ class ChipSlider extends React.Component<IProps, IState> {
                 width: '2px',
                 height: '4px',
                 borderRadius: '0px',
+                top: '45%',
             }
         })(Slider)
         this.min = this.props.marks ? this.props.marks[0].value : this.props.min;
@@ -133,13 +132,12 @@ class ChipSlider extends React.Component<IProps, IState> {
 
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        const theme: Theme = this.props.theme
         const value = [...this.state.value];
         if (value[0] == -1) value[0] = this.min;
         if (value[1] == -1) value[1] = this.max;
         return (
-            <div style={Object.assign({marginTop: '12px'}, this.props.style)}>
-                <div style={{margin: theme.spacing(0, 0.5), height: '18px'}}>
+            <DIV sx={Object.assign({marginTop: '12px'}, this.props.sx)}>
+                <DIV sx={{mx: 0.5, my: 0, height: '18px'}}>
                     <this.StyledSlider
                         value={value}
                         min={this.min}
@@ -150,19 +148,19 @@ class ChipSlider extends React.Component<IProps, IState> {
                         onChangeCommitted={this.handleChangeCommitted}
                         disabled={this.props.disabled}
                     />
-                </div>
-                <div style={{display: 'inline-flex', width: '100%', marginTop: '12px'}}>
-                    <div style={{flexGrow: 1, textAlign: 'left', fontSize: '13px', color: theme.palette.text.disabled}}>
+                </DIV>
+                <DIV sx={{display: 'inline-flex', width: '100%', marginTop: '12px'}}>
+                    <DIV sx={{flexGrow: 1, textAlign: 'left', fontSize: '13px', color: 'text.disabled'}}>
                         {`${this.props.styleValue(this.min)} ${this.props.styleUnit(this.min)}`}
-                    </div>
-                    <div style={{flexGrow: 1, textAlign: 'center'}}>
+                    </DIV>
+                    <DIV sx={{flexGrow: 1, textAlign: 'center'}}>
                         {`${this.props.label}`}
-                    </div>
-                    <div style={{flexGrow: 1, textAlign: 'right', fontSize: '13px', color: theme.palette.text.disabled}}>
+                    </DIV>
+                    <DIV sx={{flexGrow: 1, textAlign: 'right', fontSize: '13px', color: 'text.disabled'}}>
                         {`${this.props.styleValue(this.max)} ${this.props.styleUnit(this.max)}`}
-                    </div>
-                </div>
-            </div>
+                    </DIV>
+                </DIV>
+            </DIV>
         )
 	}
 
@@ -213,5 +211,3 @@ class ChipSlider extends React.Component<IProps, IState> {
         }
     }
 }
-const ThemedChipSlider = withTheme(ChipSlider)
-export {ThemedChipSlider as ChipSlider}
