@@ -6,12 +6,13 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../Global';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { Paper } from '@material-ui/core';
+import { DIV, Global } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Paper } from '@mui/material';
 
 interface IProps {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     children: JSX.Element
     launchButton?: JSX.Element
     tags: JSX.Element[]
@@ -37,56 +38,56 @@ export class LaunchSkirt extends React.Component<IProps, IState> {
         return (
             <Paper
                 elevation={1}
-                style={Object.assign({
+                sx={Object.assign({
                     width: '100%',
                     padding: '3px',
                     backgroundColor: 'var(--jp-layout-color2)',
                     borderRadius: '3px',
-                }, this.props.style)}
+                }, this.props.sx)}
                 onMouseOver={this.handleMouseOver}
                 onMouseOut={this.handleMouseOut}
             >
-                <div style={{
+                <DIV sx={{
                     display: 'inline-flex',
                     width: '100%',
                 }}>
-                    <div style={{
+                    <DIV sx={{
                         width: '100%',
                         margin: '3px 0px 0px 3px',
                         overflow: 'hidden',
                     }}>
                         {this.props.children}
-                        <div style={{
+                        <DIV sx={{
                             display: 'inline-flex',
                             flexWrap: 'wrap',
                             width: '100%',
                         }}>
-                            <div style={{
+                            <DIV sx={{
                                 display: 'inline-flex',
                                 flexGrow: 1,
                                 marginTop: '3px',
                                 marginLeft: '-3px',
                             }}>
                                 {this.props.tags.length == 0 ? (
-                                    <div style={{
+                                    <DIV sx={{
                                         minWidth: '74px',
                                         height: '20px',
                                     }}/>
                                 ) : (
                                     this.props.tags
                                 )}
-                            </div>
-                        </div>
-                    </div>
-                    <div style={{
+                            </DIV>
+                        </DIV>
+                    </DIV>
+                    <DIV sx={{
                         display: 'inline-flex',
                         margin: '6px',
                     }}>
-                        <div style={{margin: '3px'}}>
+                        <DIV sx={{margin: '3px'}}>
                             {this.props.launchButton}
-                        </div>
-                    </div>
-                </div>
+                        </DIV>
+                    </DIV>
+                </DIV>
             </Paper>
         );
     }
