@@ -14,8 +14,9 @@ import { Machine } from '../models/machine/Machine';
 import { Divider } from '@mui/material';
 import { Header, Label } from '../core';
 import FormatUtils from '../utils/FormatUtils';
-import { BillingType } from '../models/User';
 import { WarningRounded } from '@mui/icons-material';
+import { Tag } from './Tag';
+import { CustomerState } from '../core/CustomerState';
 
 interface IProps {
     sx?: SxProps<Theme>
@@ -66,12 +67,12 @@ export class MachinesPage extends React.Component<IProps, IState> {
                         getValue={() => `$${this.props.rate.toFixed(2)}/hr`}
                         lineHeight='18px' align='left' valueAlign='right'
                     />
-                    {/* {Global.user.subscriptionActive && (
+                    {/* {Global.user.isSubscribed() && (
                         <DIV sx={{opacity: 0.5, textAlign: 'center'}}>
                             Billing cycle resets on the {ordinal_suffix_of(Global.user.billingCycleAnchor.getDate())} of the month
                         </DIV>
                     )} */}
-                    {Global.user.billingType == BillingType.METERED_BILLING && Global.user.subscriptionActive && !Global.user.lastBillPaid && (
+                    {Global.user.isSubscribed() && !Global.user.lastBillPaid && (
                         <>
                             <Divider variant='middle' />
                             <DIV sx={{margin: '12px', justifyContent: 'center', height: '21px', display: 'inline-flex', width: 'calc(100% - 24px)'}}>
@@ -93,35 +94,30 @@ export class MachinesPage extends React.Component<IProps, IState> {
                 <DIV sx={{margin: '12px 0px'}}>
                     <DIV sx={{display: 'flex'}}>
                         <Header title='Usage' />
-                        {/* <Chip label='View billing' variant='filled'
-                            sx={{
-                                height: '20px',
-                                fontSize: '12px',
-                                marginTop: 'auto',
-                                marginBottom: 'auto',
-                            }}
-                            onClick={() => {}}
-                        /> */}
+                        <Tag label='View billing' onClick={() => Global.followLink(Global.Target.SettingsPopup.BillingTab)}/>
                     </DIV>
                     <Label label='Storage'
-                        getValue={() => `${FormatUtils.styleShortCapacityValue()(Global.user.fileTracker.total, FormatUtils.styleCapacityUnit()(Global.user.fileTracker.limit))} of ${FormatUtils.styleCapacityUnitValue()(Global.user.fileTracker.limit)}`}
+                        getValue={() => FormatUtils.styleStorageOrEgress(Global.user.fileTracker.total, Global.user.fileTracker.limit)}
                         lineHeight='18px' align='left' valueAlign='right'
                     />
                     <Label label='Egress'
-                        getValue={() => `${FormatUtils.styleShortCapacityValue()(Global.user.egressTotal, FormatUtils.styleCapacityUnit()(Global.user.egressLimit))} of ${FormatUtils.styleCapacityUnitValue()(Global.user.egressLimit)}`}
+                        getValue={() => FormatUtils.styleStorageOrEgress(Global.user.egressTotal, Global.user.egressLimit)}
                         lineHeight='18px' align='left' valueAlign='right'
                     />
-                    {Global.user.billingType == BillingType.CREDIT_BUCKET || !Global.user.subscriptionActive ? (
-                        <Label label='Credits'
-                            getValue={() => `${FormatUtils.formatCredit(this.props.balance)}`}
+                    {Global.user.isSubscribed() ? (
+                        <Label label='Total cost'
+                            getValue={() => {
+                                if (this.props.machineCost == null || this.props.egressCost == null || this.props.storageCost == null || this.props.serviceFeeCost == null) return '--'
+                                var sum = +FormatUtils.floorAndToFixed(this.props.machineCost, 2) + +FormatUtils.floorAndToFixed(this.props.egressCost, 2) + +FormatUtils.floorAndToFixed(this.props.storageCost, 2) + +FormatUtils.floorAndToFixed(this.props.serviceFeeCost, 2);
+                                if (sum == 0 && (this.props.machineCost > 0 || this.props.egressCost > 0 || this.props.storageCost > 0 || this.props.serviceFeeCost > 0)) return '< $0.01'
+                                return `${FormatUtils.formatCost(sum)}`;
+                            }}
                             lineHeight='18px' align='left' valueAlign='right'
                         />
-                    ) : (
-                        <Label label='Total cost'
-                        getValue={() => {
-                            if (this.props.machineCost == null || this.props.egressCost == null || this.props.storageCost == null || this.props.serviceFeeCost == null) return '--'
-                            return `$${(+(this.props.machineCost.toFixed(2)) + +(this.props.egressCost.toFixed(2)) + +(this.props.storageCost.toFixed(2)) + +(this.props.serviceFeeCost.toFixed(2))).toFixed(2)}`
-                        }}
+                        
+                    ) : Global.user.customerState == CustomerState.FREE_TRIAL && (
+                        <Label label='Credits'
+                            getValue={() => `${FormatUtils.formatCredit(this.props.balance)}`}
                             lineHeight='18px' align='left' valueAlign='right'
                         />
                     )}
