@@ -14,7 +14,7 @@ import { withStyles } from '@mui/styles';
 import { Close, OpenInNew } from '@mui/icons-material';
 
 import { ShadowedDivider } from '../../core';
-import DataConnectorBrowser, { DataConnectorMetadata } from './dataConnectorBrowser/DataConnectorBrowser';
+import IntegrationBrowser, { IntegrationMetadata, IntegrationType } from './IntegrationBrowser/IntegrationBrowser';
 
 const StyledDialog = withStyles({
     paper: {
@@ -30,7 +30,7 @@ interface IProps {
     sx?: SxProps<Theme>
     onOpen?: () => void
     onClose?: () => void
-    onDataConnectorsAdded: (paths: DataConnectorMetadata[]) => void
+    onDataConnectorsAdded: (paths: IntegrationMetadata[]) => void
     openUserDialogTo?: (page: number) => Promise<void>
 }
 
@@ -41,7 +41,7 @@ interface IState {
 export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
     private _isMounted = false
 
-    private getSelectedDataConnectors: () => DataConnectorMetadata[] = () => []
+    private getSelectedDataConnectors: () => IntegrationMetadata[] = () => []
 
     constructor(props: IProps) {
         super(props);
@@ -79,13 +79,11 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
             <DIV sx={Object.assign({display: 'inline-flex', width: '50%'}, this.props.sx)} >
                 <SkinnyButton
                     onClick={this.handleClickOpen}
-                    variant='contained'
                     disableElevation
-                    color='primary'
-                    sx={{
-                        margin: '0px 6px 6px 6px',
-                        width: '100%',
-                    }}
+                    color={"primary"} 
+                    variant={"contained"}
+                    fullWidth
+                    sx={{ margin: '6px' }}
                 >
                     + Connector
                 </SkinnyButton>
@@ -143,7 +141,7 @@ export class AddDataConnectorsPopup extends React.Component<IProps, IState> {
                         </IconButton>
 					</DialogTitle>
                     <ShadowedDivider />
-                    <DataConnectorBrowser sx={{flexGrow: 1, height: '100%', maxHeight: 'calc(100% - 60px - 60px - 2px)'}} onAdd={this.handleAdd} getSelected={(getSelectedDataConnectors: () => DataConnectorMetadata[]) => this.getSelectedDataConnectors = getSelectedDataConnectors} />
+                    <IntegrationBrowser sx={{flexGrow: 1, height: '100%', maxHeight: 'calc(100% - 60px - 60px - 2px)'}} type={IntegrationType.DATA_CONNECTOR} onAdd={this.handleAdd} getSelected={(getSelectedDataConnectors: () => IntegrationMetadata[]) => this.getSelectedDataConnectors = getSelectedDataConnectors} />
                     <Divider />
                     <DIV sx={{display: 'inline-flex', margin: '6px 100px', height: '60px'}}>
                         <DIV sx={{display: 'inline-flex', flexGrow: 1, margin: 'auto'}}>
