@@ -11,12 +11,12 @@ import { DIV, Global } from '../../Global';
 import { IconButton } from '@mui/material';
 import { Close as CloseIcon } from '@mui/icons-material';
 
-import DataConnectorDirListingItemIcon from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
-import { DataConnectorUploadConfig } from '../../models/DataConnectorUploadConfig';
+import DataConnectorDirListingItemIcon from './IntegrationBrowser/IntegrationDirListingItemIcon';
 import { Colors } from '../../Colors';
+import { DataConnectorConfig } from '../../models/IntegrationConfig';
 
 interface RDCProps {
-    dataConnector: DataConnectorUploadConfig,
+    dataConnector: DataConnectorConfig,
     handleFileDelete: () => void,
     noLongerExists?: boolean,
 }
