@@ -6,8 +6,9 @@
 **/
 
 import * as React from 'react'
+import { Global, SPAN } from '../../../Global';
+
 import { FileMetadata } from './FileBrowser'
-import { Global } from '../../../Global';
 
 interface IProps {
     serverRoot: string
@@ -27,7 +28,7 @@ export default class BreadCrumbHome extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
-                <span className='jp-BreadCrumbs-home jp-BreadCrumbs-item' title={this.props.serverRoot} onClick={() => this.props.onOpen(this.props.file)}>
+                <SPAN className='jp-BreadCrumbs-home jp-BreadCrumbs-item' title={this.props.serverRoot} onClick={() => this.props.onOpen(this.props.file)}>
                     <svg width='16' viewBox='0 0 24 24' style={{
                         height: '16px',
                         bottom: '1px',
@@ -38,8 +39,8 @@ export default class BreadCrumbHome extends React.Component<IProps, IState> {
                     }}>
                         <path className='jp-icon3 jp-icon-selectable' fill='#616161' d='M10 4H4c-1.1 0-1.99.9-1.99 2L2 18c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V8c0-1.1-.9-2-2-2h-8l-2-2z' />
                     </svg>
-                </span>
-                <span>/</span>
+                </SPAN>
+                <SPAN>/</SPAN>
             </>
         )
     }
