@@ -27,7 +27,7 @@ export default class FilterBox extends React.Component<IProps, IState> {
                 <DIV className='bp3-input-group jp-InputGroup'>
                     <input
                         type='text'
-                        placeholder='Filter files by name'
+                        placeholder='Filter files and directories by name'
                         className='bp3-input'
                         style={{paddingRight: '0px'}}
                         onChange={(event) => this.props.onChange(event.currentTarget.value)}
