@@ -16,7 +16,7 @@ import { ServerConnection } from '@jupyterlab/services';
 
 import { Header, Switch, TextBox } from '../../core';
 import FormatUtils from '../../utils/FormatUtils';
-import DataConnectorBrowser, { DataConnectorMetadata } from '../deploy/dataConnectorBrowser/DataConnectorBrowser';
+import IntegrationBrowser, { DataConnectorMetadata, IntegrationMetadata, IntegrationType } from '../deploy/IntegrationBrowser/IntegrationBrowser';
 import { AmazonS3ConnectorPopup } from '../deploy/AmazonS3ConnectorPopup';
 import { GoogleCloudStorageConnectorPopup } from '../deploy/GoogleCloudStorageConnectorPopup';
 import { GoogleDriveConnectorPopup } from '../deploy/GoogleDriveConnectorPopup';
@@ -32,6 +32,7 @@ import { PhoneTextBox } from '../../core/PhoneTextBox';
 import { SubscriptionEnded } from './SubscriptionEnded';
 import { CustomerState } from '../../core/CustomerState';
 import { FreeTrialEnded } from './FreeTrialEnded';
+import { EnvironmentVariablePopup } from '../../core/EnvironmentVariablePopup';
 
 // Properties from parent
 interface IAccountPreferencesSubMenuProps {
@@ -484,19 +485,19 @@ export class AccountBillingSubMenu extends React.Component<IAccountBillingSubMen
 }
 
 // Properties from parent
-interface IAccountConnectorsSubMenuProps {
+interface IAccountIntegrationsSubMenuProps {
 	sx?: SxProps<Theme>
 }
 
-interface IAccountConnectorsSubMenuState {
+interface IAccountIntegrationsSubMenuState {
     dataConnectors: DataConnectorMetadata[],
     browserKey: number,
 }
 
-export class AccountConnectorsSubMenu extends React.Component<IAccountConnectorsSubMenuProps, IAccountConnectorsSubMenuState> {
+export class AccountIntegrationsSubMenu extends React.Component<IAccountIntegrationsSubMenuProps, IAccountIntegrationsSubMenuState> {
     private _isMounted = false
 
-    constructor(props: IAccountConnectorsSubMenuProps) {
+    constructor(props: IAccountIntegrationsSubMenuProps) {
         super(props);
         this.state = {
             dataConnectors: [],
@@ -511,7 +512,7 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
 
     public request = async () => {
         const settings = ServerConnection.makeSettings();
-		const url = settings.baseUrl + 'optumi/get-data-connectors'
+		const url = settings.baseUrl + 'optumi/get-integrations'
 		return ServerConnection.makeRequest(url, {}, settings).then(response => {
 			if (response.status !== 200) throw new ServerConnection.ResponseError(response);
 			return response.json()
@@ -524,17 +525,18 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
             <>
                 <DIV sx={Object.assign({}, this.props.sx)}>
                     <DIV sx={{display: 'inline-flex', margin: '6px'}}>
-                        <Header title='Existing connectors' sx={{ lineHeight: '24px', margin: '6px 6px 6px 11px' }} />
+                        <Header title='Existing integrations' sx={{ lineHeight: '24px', margin: '6px 6px 6px 11px' }} />
                     </DIV>
                     <Divider />
-                    <DataConnectorBrowser
+                    <IntegrationBrowser
                         key={this.state.browserKey}
                         sx={{
                             maxHeight: 'calc(100% - 60px - 2px)',
                         }}
-                        handleDelete={(dataConnectorMetadata: DataConnectorMetadata) => {
+                        type={IntegrationType.ALL}
+                        handleDelete={(dataConnectorMetadata: IntegrationMetadata) => {
                             const settings = ServerConnection.makeSettings();
-                            const url = settings.baseUrl + "optumi/remove-data-connector";
+                            const url = settings.baseUrl + "optumi/remove-integration";
                             const init: RequestInit = {
                                 method: 'POST',
                                 body: JSON.stringify({
@@ -557,7 +559,7 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
                     />
                     <Divider sx={{marginTop: '33px'}}/>
                     <DIV sx={{display: 'inline-flex', margin: '6px'}}>
-                        <Header title='New connectors' sx={{ lineHeight: '24px', margin: '6px 6px 6px 11px'  }} />
+                        <Header title='New integrations' sx={{ lineHeight: '24px', margin: '6px 6px 6px 11px'  }} />
                     </DIV>
                     <Divider />
                     <DIV sx={{marginBottom: '6px'}} />
@@ -567,6 +569,7 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
                     <GoogleDriveConnectorPopup onClose={this.forceNewBrowser} />
                     <KaggleConnectorPopup onClose={this.forceNewBrowser} />
                     <WasabiConnectorPopup onClose={this.forceNewBrowser} />
+                    <EnvironmentVariablePopup onClose={this.forceNewBrowser} />
                 </DIV>
             </>
         )
@@ -574,7 +577,7 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
 
     public componentDidMount = () => {
         this._isMounted = true
-        this.request().then(json => this.safeSetState({dataConnectors: json.connectors}))
+        this.request().then(json => this.safeSetState({integrations: json.integrations}))
     }
 
     public componentWillUnmount = () => {
@@ -603,7 +606,7 @@ export class AccountConnectorsSubMenu extends React.Component<IAccountConnectors
 		}
 	}
 
-    public shouldComponentUpdate = (nextProps: IAccountConnectorsSubMenuProps, nextState: IAccountConnectorsSubMenuState): boolean => {
+    public shouldComponentUpdate = (nextProps: IAccountIntegrationsSubMenuProps, nextState: IAccountIntegrationsSubMenuState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -715,11 +718,3 @@ export class AccountStorageSubMenu extends React.Component<IAccountStorageSubMen
         }
     }
 }
-export class TeamSubMenu extends React.Component<IAccountStorageSubMenuProps, IAccountStorageSubMenuState> {
-    public render = (): JSX.Element => {
-		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        return (
-            <Header title='Members' />
-        )
-    }
-}
