@@ -9,8 +9,6 @@ export { Header, SubHeader } from './Header'
 export { IntentSlider } from './IntentSlider'
 export { Label } from './Label'
 export { ShadowedDivider } from './ShadowedDivider'
-export { Slider } from './Slider'
 export { Switch } from './Switch'
 export { TextBox } from './TextBox'
-export { TextBoxDropdown } from './TextBoxDropdown'
 export { Dropdown } from './Dropdown'
