@@ -6,8 +6,8 @@
 **/
 
 import * as React from 'react'
+import { DIV, Global } from '../../Global';
 
-import { Global } from '../../Global';
 import { Markdown as MarkdownWrapper } from '../Markdown';
 
 interface IProps {
@@ -22,9 +22,9 @@ export default class Markdown extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div className='jp-RenderedMarkdown jp-MarkdownOutput jp-RenderedHTMLCommon'>
+            <DIV className='jp-RenderedMarkdown jp-MarkdownOutput jp-RenderedHTMLCommon'>
                 <MarkdownWrapper text={this.props.cell.source} />
-            </div>
+            </DIV>
         )
     }
     
