@@ -9,28 +9,29 @@ import { Global } from "../Global"
 
 import { ServerConnection } from '@jupyterlab/services';
 
-import { DataConnectorMetadata } from '../components/deploy/dataConnectorBrowser/DataConnectorBrowser';
+import { DataConnectorMetadata } from '../components/deploy/IntegrationBrowser/IntegrationBrowser';
 import { FileMetadata } from "../components/deploy/fileBrowser/FileBrowser"
 import FileServerUtils from "../utils/FileServerUtils"
-import { DataConnectorUploadConfig } from './DataConnectorUploadConfig';
 import { FileUploadConfig } from './FileUploadConfig';
+import { DataConnectorConfig } from "./IntegrationConfig";
 
 export class FileChecker {
     // Here is where we will keep a list of the file paths that were entered successfully but no longer exist on the disk
     private localProblemFiles: string[] = []
     private cloudProblemFiles: string[] = []
     private problemDataConnectors: string[] = []
+    private problemEnvironmentVariables: string[] = []
 
     refreshing: boolean = false
-    filesTimeout: number = null
-    dataConnectorsTimeout: number = null
+    filesTimeout: NodeJS.Timeout = null
+    dataConnectorsTimeout: NodeJS.Timeout = null
 
     public start() {
         if (!this.refreshing) {
             this.refreshing = true
 
             this.refreshFiles(true)
-            this.refreshDataConnectors(true)
+            this.refreshIntegrations(true)
         }
     }
 
@@ -40,7 +41,7 @@ export class FileChecker {
         if (this.dataConnectorsTimeout != null) clearTimeout(this.dataConnectorsTimeout)
     }
 
-    public getTriangle(files: FileUploadConfig[], dataConnectors: DataConnectorUploadConfig[]): [boolean, boolean] {
+    public getTriangle(files: FileUploadConfig[], dataConnectors: DataConnectorConfig[]): [boolean, boolean] {
         var yellowTriangle = false
         var redTriangle = false
         for (let file of files) {
@@ -75,6 +76,10 @@ export class FileChecker {
         return this.problemDataConnectors.includes(name);
     }
 
+    public environmentVariableMissing(name: string): boolean {
+        return this.problemEnvironmentVariables.includes(name);
+    }
+
     public removeFile(path: string) {
         if (this.localProblemFiles.includes(path)) this.localProblemFiles = this.localProblemFiles.filter(x => x != path);
         if (this.cloudProblemFiles.includes(path)) this.cloudProblemFiles = this.cloudProblemFiles.filter(x => x != path);
@@ -84,6 +89,10 @@ export class FileChecker {
         if (this.problemDataConnectors.includes(name)) this.problemDataConnectors = this.problemDataConnectors.filter(x => x != name);
     }
 
+    public removeEnvironmentVariable(name: string) {
+        if (this.problemEnvironmentVariables.includes(name)) this.problemEnvironmentVariables = this.problemEnvironmentVariables.filter(x => x != name);
+    }
+
     public refreshFiles = async (poll: boolean = true) => {
         if (this.refreshing) {
             try {
@@ -122,18 +131,18 @@ export class FileChecker {
         }
     }
 
-    public refreshDataConnectors = async (poll: boolean = true) => {
+    public refreshIntegrations = async (poll: boolean = true) => {
         if (this.refreshing) {
             try {
                 const optumi = Global.metadata.getMetadata().config;
-                const dataConnectors = optumi.upload.dataConnectors;
+                const dataConnectors = optumi.dataConnectors
                 
                 const settings = ServerConnection.makeSettings();
-                const url = settings.baseUrl + "optumi/get-data-connectors";
+                const url = settings.baseUrl + "optumi/get-integrations";
                 const dataConnectorsFromController: DataConnectorMetadata[] = await (ServerConnection.makeRequest(url, {}, settings).then(response => {
                     if (response.status !== 200) throw new ServerConnection.ResponseError(response);
                     return response.json();
-                }).then((json: any) => json.connectors));
+                }).then((json: any) => json.integrations));
 
                 for (var dataConnector of dataConnectors) {
                     if (!this.refreshing) break;
@@ -149,7 +158,7 @@ export class FileChecker {
             }
             if (poll) {
                 if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-                this.dataConnectorsTimeout = setTimeout(this.refreshDataConnectors, 60000);
+                this.dataConnectorsTimeout = setTimeout(this.refreshIntegrations, 60000);
             }
         }
     }
