@@ -27,7 +27,7 @@ export class GraphicsConfig {
         this.required = map.required == undefined ? false : map.required;
         this.rating = map.rating || [-1, -1, -1];
         this.score = map.score || [-1, -1, -1];
-        this.cores = map.cores || [1, -1, -1];
+        this.cores = map.cores || [-1, -1, -1];
         this.memory = map.memory || [-1, -1, -1];
         this.frequency = map.frequency || [-1, -1, -1];
         this.boardType = map.boardType || "U";  // Default is U for unspecified
