@@ -58,19 +58,17 @@ export class AppTracker {
 		this._apps.unshift(app);
 		if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
 		this._appsChanged.emit(this._apps);
-		app.changed.connect(() => {
+		app.globalChangedTrigger = () => {
 			if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-			return this._appsChanged.emit(this._apps)
-		}, this);
+			this._appsChanged.emit(this._apps)
+		}
+		app.changed.connect(app.globalChangedTrigger);
 	}
 
 	public removeApp(uuid: string) {
 		var app: App = this._apps.filter((app: App) => app.uuid == uuid)[0];
 		this._apps = this._apps.filter((app: App) => app.uuid != uuid);
-		app.changed.disconnect(() => {
-			if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
-			return this._appsChanged.emit(this._apps)
-		}, this);
+		app.changed.disconnect(app.globalChangedTrigger);
 		if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
 		this._appsChanged.emit(this._apps);
 	}
@@ -79,6 +77,10 @@ export class AppTracker {
 		return this._apps.filter((app: App) => app.getAppStatus() != Status.COMPLETED).length;
 	}
 
+	public getNum() {
+		return this._apps.length;
+	}
+
 	// If we are polling, send a new request 2 seconds after completing the previous request
 	private  appPollDelay = 2000;
 	private receiveAppUpdates() {
@@ -145,7 +147,7 @@ export class AppTracker {
 		}
 	}
 	// If we are polling, send a new request 1 seconds after completing the previous request
-	private modPollingDelay = 1000;
+	private modPollingDelay = 2000;
 	private async receiveModuleUpdates() {
 		if (!this._polling) return;
 		const user = Global.user;
@@ -225,4 +227,8 @@ export class AppTracker {
 			setTimeout(() => this.receiveModuleUpdates(), this.modPollingDelay);
 		}
 	}
+
+	public stopPolling() {
+		this._polling = false;
+	}
 }
