@@ -26,11 +26,13 @@ export class IdentityAppComponent extends React.Component<IProps, IState> {
         const lightweightApp = this.props.app
         return (
 				<DIV sx={{paddingLeft: '3px'}}> {/* the padding is 7px because the height it needs to take up is 36 and the height of this 16px font is 22px */}
-					<ExtraInfo reminder={lightweightApp.path}>
-						<DIV sx={{paddingBottom: '7px', fontSize: 'var(--jp-ui-font-size1)', lineHeight: '1', fontWeight: 'normal', whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis'}}>
-							{lightweightApp.name}
-						</DIV>
-					</ExtraInfo>
+					<DIV sx={{paddingBottom: '7px', display: 'inline-flex'}}>
+						<ExtraInfo reminder={lightweightApp.path}>
+							<DIV sx={{margin: 'auto', fontSize: 'var(--jp-ui-font-size1)', lineHeight: '1', fontWeight: 'normal', whiteSpace: 'nowrap', textOverflow: 'ellipsis'}}>
+								{lightweightApp.name}
+							</DIV>
+						</ExtraInfo>
+					</DIV>
 					<AnnotationInput
 						getValue={() => lightweightApp.config.annotation}
 						saveValue={(value: string) => {
