@@ -13,6 +13,7 @@ import { AppLaunchComponent } from './AppLaunchComponent';
 import { IdentityAppComponent } from './IdentityAppComponent';
 import { TrackedOptumiMetadata } from '../OptumiMetadataTracker';
 import { OptumiMetadata } from '../OptumiMetadata';
+import { Machine } from '../machine/Machine';
 
 export class LightweightApp {
     uuid: string
@@ -44,8 +45,8 @@ export class LightweightApp {
         return 0;
     }
 
-    public getLaunchComponent(disabled: boolean): React.CElement<any, AppLaunchComponent> {
-        return React.createElement(AppLaunchComponent, {key: this.path, lightweightApp: this, disabled: disabled});
+    public getLaunchComponent(machine: Machine, balance: number): React.CElement<any, AppLaunchComponent> {
+        return React.createElement(AppLaunchComponent, {key: this.path, lightweightApp: this, machine: machine, balance: balance});
     }
 
     public getIdentityComponent(): React.CElement<any, IdentityAppComponent> {
