@@ -6,11 +6,11 @@
 **/
 
 import * as React from 'react';
-import { DIV, Global, SPAN } from '../../Global';
+import { DIV, Global } from '../../Global';
 
 import { Button, Dialog, DialogContent, DialogTitle, IconButton, Tab, Tabs } from '@mui/material';
 import { CSSProperties, withStyles } from '@mui/styles';
-import { MoreVert as PopupIcon, Close as CloseIcon, OpenInNew as OpenInNewIcon } from '@mui/icons-material';
+import { MoreVert, Close, OpenInNew, WarningRounded, GetApp } from '@mui/icons-material';
 
 import { App } from './App';
 import { ScrollableDiv } from '../../components/monitor/ScrollableDiv';
@@ -23,6 +23,9 @@ import FileServerUtils from '../../utils/FileServerUtils';
 import { NotificationContent } from '../../core/NotificationContent';
 import { OptumiConfig } from '../OptumiConfig';
 import { ResourceGraph } from '../../core/ResourceGraph';
+import { Colors } from '../../Colors';
+import { Snackbar } from '../Snackbar';
+import ExtraInfo from '../../utils/ExtraInfo';
 
 const StyledDialog = withStyles({
     paper: {
@@ -50,7 +53,6 @@ interface IProps {
 	onClose?: () => void
     onMouseOver?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
     onMouseOut?: (event: React.MouseEvent<HTMLButtonElement, MouseEvent>) => void
-    openUserDialogTo?: (page: number) => Promise<void> // This is somewhat spaghetti code-y, maybe think about revising
 }
 
 interface IState {
@@ -105,17 +107,8 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
             newPath = inc == 0 ? path : path.replace('.', '(' + inc + ').');
         }
 
-        if (app.interactive) {
-            const module = app.modules[0];
-            for (let file of module.files) {
-                if (file.path === '~/' + app.path) {
-                    Global.user.fileTracker.downloadFiles(app.path, [file], false, [newPath]).then(() => { Global.docManager.open(newPath) });
-                }
-            }
-        } else {
-            var notebook: any = app.notebook;
-            FileServerUtils.saveNotebook(newPath, notebook).then((success: boolean) => { Global.docManager.open(newPath) });
-        }
+        var notebook: any = app.notebook;
+        FileServerUtils.saveNotebook(newPath, notebook).then((success: boolean) => { Global.docManager.open(newPath) });
         
         // Close the dialog
         this.handleClose();
@@ -138,7 +131,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                 onMouseOver={this.handleMouseOver}
                 onMouseOut={this.handleMouseOut}
             >
-                <PopupIcon
+                <MoreVert
                     sx={{
                         width: '30px',
                         height: '30px',
@@ -180,7 +173,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                 color='primary'
                                 onClick={this.openSession}
                                 disabled={app.getAppStatus() == Status.COMPLETED || !(app.modules.length > 0 && app.modules[0].sessionReady)}
-                                endIcon={<OpenInNewIcon />}
+                                endIcon={<OpenInNew />}
                             >
                                 Open session
                             </Button>
@@ -192,7 +185,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                             color='primary'
                             onClick={this.openAsNewNotebook}
                             disabled={app.getAppStatus() != Status.COMPLETED}
-                            endIcon={<OpenInNewIcon />}
+                            endIcon={<OpenInNew />}
                         >
                             Open as a new notebook
                         </Button>
@@ -208,7 +201,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                             margin: '6px',
                         }}
                     >
-                        <CloseIcon
+                        <Close
                             sx={{
                                 width: '30px',
                                 height: '30px',
@@ -233,7 +226,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                 >
                                     <Tab
                                         disableRipple
-                                        label='SUMMARY'
+                                        label='Summary'
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
@@ -243,7 +236,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     />
                                     {!app.interactive && <Tab
                                         disableRipple
-                                        label='NOTIFICATIONS'
+                                        label='Notifications'
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
@@ -253,7 +246,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     />}
                                     {!app.interactive && <Tab
                                         disableRipple
-                                        label='NOTEBOOK'
+                                        label='Notebook'
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
@@ -263,7 +256,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     />}
                                     <Tab
                                         disableRipple
-                                        label='FILES'
+                                        label='Files'
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
@@ -283,7 +276,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     /> */}
                                     <Tab
                                         disableRipple
-                                        label='MACHINE'
+                                        label='Machine'
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
@@ -293,7 +286,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     />
                                     {app.modules.length > 0 && /*app.interactive &&*/ <Tab
                                         disableRipple
-                                        label='LOG'
+                                        label='Log'
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
@@ -303,7 +296,7 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     />}
                                     {Global.user.showMonitoringEnabled && <Tab
                                         disableRipple
-                                        label='GRAPH'
+                                        label='Graph'
                                         sx={{
                                             padding: '0px',
                                             minWidth: 'auto',
@@ -359,7 +352,28 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                     )}
                                     <br/>
                                     {/* The must have unique key error apparently applies to fragments as well, despite not being able to hold keys */}
-                                    {(app.initializing.messages + app.preparing.messages + app.running.messages).split('\n').map((value: string) => (<SPAN sx={{whiteSpace: 'pre'}} key={value + i++}>{app.adjustMessage(value)}<br /></SPAN>))}
+                                    {app.initializing.messages.concat(app.preparing.messages).concat(app.running.messages).filter(value => value[0].trim().length > 0).map((value: [string, string, boolean]) => (
+                                        <>
+                                            <DIV sx={{display: 'inline-flex', whiteSpace: 'pre'}} key={value[0] + i++}>
+                                                {value[2] && (
+                                                    <>
+                                                        {value[1] == 'error' ? (
+                                                            <WarningRounded sx={{color: Colors.ERROR, height: '16px', width: '24px'}}/>
+                                                        ) : (value[1] == 'warning' ? (
+                                                            <WarningRounded sx={{color: Colors.WARNING, height: '16px', width: '24px'}}/>
+                                                        ) : (
+                                                            <DIV sx={{width: '24px'}} />
+                                                        ))}
+                                                    </>
+                                                )}
+                                                <DIV sx={{margin: 'auto'}}>
+                                                    {app.adjustMessage(value[0])}
+                                                    {/* {value[0] + " " + value[1] + " " + value[2]} */}
+                                                </DIV>
+                                            </DIV>
+                                            <br />
+                                        </>
+                                    ))}
                                 </DIV>
                             ) : this.state.selectedPanel == Page.NOTIFICATIONS ? (
                                 <DIV sx={{padding: '20px'}}>
@@ -367,7 +381,6 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                         getValue={() => app.config}
                                         saveValue={(config: OptumiConfig) => app.config = config}
                                         disabled={app.getAppStatus() == Status.COMPLETED}
-                                        openUserDialogTo={this.props.openUserDialogTo}
                                         handleClose={this.handleClose}
                                     />
                                 </DIV>
@@ -379,7 +392,9 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                 <DIV sx={{padding: '8px'}}>
                                     {app.interactive && app.getAppStatus() != Status.COMPLETED ? (
                                         <DIV sx={{padding: '12px'}}>
-                                            Files will appear here after your session has completed. Until then, you can upload/download files directly from the session tab.
+                                            For active sessions, upload/download files directly from the session tab using the JupyterLab browser.
+                                            <br />
+                                            Files will appear here when the session has finished.
                                         </DIV>
                                     ) : (
                                         <FileList app={app} />
@@ -397,12 +412,40 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
                                 </DIV>
                                 
                             ) : this.state.selectedPanel == Page.LOG ? (
-                                <DIV sx={{overflow: 'hidden', width: '100%', height: '100%'}}>
+                                <DIV sx={{overflow: 'hidden', display: 'flex', flexDirection: 'column', height: '100%'}}>
                                     <ScrollableDiv
                                         key='output'
                                         source={Object.assign([], app.modules[0].output.filter(x => !x.line.startsWith('  warnings.warn(')))}
                                         autoScroll={true}
                                     />
+                                    {app.modules[0].output.length > 0 && (
+                                        <ExtraInfo reminder={'Download to ~/' + app.path.replace('.ipynb', '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.log')}>
+                                            <Button
+                                                sx={{margin: '12px'}}
+                                                onClick={async () => {
+                                                    var path = app.path.replace('.ipynb', '-' + (app.annotationOrRunNum.replace(/\W/g, '')) + '.log');
+                                                    var inc = 0;
+
+                                                    var newPath = path;
+                                                    while ((await FileServerUtils.checkIfPathExists(newPath))[0]) {
+                                                        inc++;
+                                                        newPath = inc == 0 ? path : path.replace('.', '(' + inc + ').');
+                                                    }
+
+                                                    if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
+                                                    Global.snackbarEnqueue.emit(new Snackbar(
+                                                        "Downloading ~/" + newPath,
+                                                        { variant: 'success', key: new Date().toISOString() }
+                                                    ));
+
+                                                    FileServerUtils.saveFile(newPath, app.modules[0].output.filter(x => !x.line.startsWith('  warnings.warn(')).map(x => x.line).join(''))
+                                                }}
+                                                endIcon={<GetApp />}
+                                            >
+                                                Download log file
+                                            </Button>
+                                        </ExtraInfo>
+                                    )}
                                 </DIV>
                             ) : this.state.selectedPanel == Page.GRAPH && (
                                 <DIV sx={{overflow: 'hidden', width: '100%', height: '100%'}}>
@@ -416,11 +459,17 @@ export class PopupAppComponent extends React.Component<IProps, IState> {
         </>;
     }
 
+	private handleAppChange = () => {
+		this.forceUpdate()
+	}
+
     public componentDidMount = () => {
         this._isMounted = true
+		this.props.app.changed.connect(this.handleAppChange)
     }
 
     public componentWillUnmount = () => {
+		this.props.app.changed.disconnect(this.handleAppChange)
         this._isMounted = false
     }
 
